@@ -92,7 +92,7 @@ enum {
 
 struct _DasherPreferencesDialoguePrivate {
   GtkWidget *pPreferencesWindow;
-  DasherEditorInternal *pEditor;
+  DasherEditor *pEditor;
   DasherAppSettings *pAppSettings;
   GtkWindow *pMainWindow;
 
@@ -215,11 +215,12 @@ static void dasher_preferences_dialogue_init(DasherPreferencesDialogue *pDasherC
 static void dasher_preferences_dialogue_destroy(GObject *pObject) {
   // FIXME - I think we need to chain up through the finalize methods
   // of the parent classes here...
+  delete DASHER_PREFERENCES_DIALOGUE(pObject)->private_data;
 }
 
 // Public methods
 
-DasherPreferencesDialogue *dasher_preferences_dialogue_new(GladeXML *pGladeWidgets, DasherEditorInternal *pEditor, DasherAppSettings *pAppSettings, GtkWindow *pMainWindow) {
+DasherPreferencesDialogue *dasher_preferences_dialogue_new(GladeXML *pGladeWidgets, DasherEditor *pEditor, DasherAppSettings *pAppSettings, GtkWindow *pMainWindow) {
   DasherPreferencesDialogue *pDasherControl;
   pDasherControl = (DasherPreferencesDialogue *)(g_object_new(dasher_preferences_dialogue_get_type(), NULL));
 
@@ -322,6 +323,7 @@ extern "C" gboolean dasher_preferences_refresh_foreach_function(GtkTreeModel *pM
   gtk_tree_model_get(pModel, pIter, 2, &szComparison, -1);
 
   if(!strcmp(szTarget, szComparison)) {
+    free(szComparison);
     // Todo: set selection here?
     gtk_tree_view_set_cursor((GtkTreeView *)pPointers[1], pPath, NULL, false);
 
@@ -329,6 +331,8 @@ extern "C" gboolean dasher_preferences_refresh_foreach_function(GtkTreeModel *pM
 
     return true;
   }
+
+  free(szComparison);
   
   return false;
 }
@@ -414,7 +418,7 @@ void dasher_preferences_dialogue_populate_list(DasherPreferencesDialogue *pSelf,
   GtkTreeViewColumn *pColumn;
   
   pRenderer = gtk_cell_renderer_text_new();
-  pColumn = gtk_tree_view_column_new_with_attributes("Action", pRenderer, "text", 2, NULL);
+  pColumn = gtk_tree_view_column_new_with_attributes(_("Action"), pRenderer, "text", 2, NULL);
   gtk_tree_view_append_column(pView, pColumn);
 
   GtkTreeIter oIter;
@@ -440,7 +444,9 @@ void dasher_preferences_dialogue_populate_list(DasherPreferencesDialogue *pSelf,
 
     // This is potentially horrible - maybe rethink in the future;
     gtk_list_store_set(pStore, &oIter, 0, iParameter, 1, pHelper, 2, szName, 3, szName, 4, pHelperWindow, 5, pHelperWindowRef, -1);
- 
+
+    delete[] szName;
+
     if(!strcmp(szCurrentFilter, szCurrentValue)) {
       gtk_tree_selection_select_iter(pSelection, &oIter);
       if(pHelper) {
@@ -470,7 +476,8 @@ extern "C" void on_list_selection(GtkTreeSelection *pSelection, gpointer pUserDa
     gtk_tree_model_get(pModel, &oIter, 0, &iParameter, 1, &pHelper, 2, &szValue, 4, &pHelperWindow, 5, &pHelperWindowRef, -1);
     
     dasher_app_settings_set_string(pPrivate->pAppSettings, iParameter, szValue);
-    
+    free(szValue);
+
     if(pHelper) {
       gtk_widget_set_sensitive(GTK_WIDGET(pHelper), pHelperWindow != NULL);
       *((GtkWidget **)pHelperWindowRef) = (GtkWidget *)pHelperWindow;
@@ -884,7 +891,15 @@ extern "C" void uniform_changed(GtkHScale *hscale) {
   //  DasherPreferencesDialoguePrivate *pPrivate = DASHER_PREFERENCES_DIALOGUE_PRIVATE(pSelf);
   DasherPreferencesDialoguePrivate *pPrivate = DASHER_PREFERENCES_DIALOGUE_PRIVATE(g_pPreferencesDialogue); // TODO: Fix NULL
 
-  dasher_app_settings_set_long(pPrivate->pAppSettings, LP_UNIFORM, int (GTK_RANGE(hscale)->adjustment->value * 10));
+  
+  int iValue = (int)(GTK_RANGE(hscale)->adjustment->value * 10);
+
+  if(iValue < 50) {
+    iValue = 50;
+    gtk_range_set_value(GTK_RANGE(glade_xml_get_widget(pPrivate->pGladeXML, "uniformhscale")), 5.0);
+  }
+  
+  dasher_app_settings_set_long(pPrivate->pAppSettings, LP_UNIFORM, iValue);
 }
 
 extern "C" gboolean show_helper_window(GtkWidget *pWidget, gpointer *pUserData) {
@@ -938,27 +953,29 @@ void dasher_preferences_dialogue_populate_actions(DasherPreferencesDialogue *pSe
 
   GtkTreeIter oIter;
 
-  dasher_editor_internal_actions_start(pPrivate->pEditor);
+  // TODO: Reimplement this
 
-  while(dasher_editor_internal_actions_more(pPrivate->pEditor)) {
-    gtk_list_store_append(pPrivate->pListStore, &oIter);
+//   dasher_editor_actions_start(pPrivate->pEditor);
 
-    const gchar *szName;
-    gint iID;
-    gboolean bShow;
-    gboolean bControl;
-    gboolean bAuto;
+//   while(dasher_editor_actions_more(pPrivate->pEditor)) {
+//     gtk_list_store_append(pPrivate->pListStore, &oIter);
 
-    dasher_editor_internal_actions_get_next(pPrivate->pEditor, &szName, &iID, &bShow, &bControl, &bAuto),
+//     const gchar *szName;
+//     gint iID;
+//     gboolean bShow;
+//     gboolean bControl;
+//     gboolean bAuto;
 
-    gtk_list_store_set(pPrivate->pListStore, &oIter, 
-		       ACTIONS_ID_COLUMN, iID,
-		       ACTIONS_NAME_COLUMN, szName,
-		       ACTIONS_SHOW_COLUMN, bShow,
-		       ACTIONS_CONTROL_COLUMN, bControl,
-		       ACTIONS_AUTO_COLUMN, bAuto,
-		       -1);
-  }
+//     dasher_editor_actions_get_next(pPrivate->pEditor, &szName, &iID, &bShow, &bControl, &bAuto),
+
+//     gtk_list_store_set(pPrivate->pListStore, &oIter, 
+// 		       ACTIONS_ID_COLUMN, iID,
+// 		       ACTIONS_NAME_COLUMN, szName,
+// 		       ACTIONS_SHOW_COLUMN, bShow,
+// 		       ACTIONS_CONTROL_COLUMN, bControl,
+// 		       ACTIONS_AUTO_COLUMN, bAuto,
+// 		       -1);
+//   }
   
   GtkCellRenderer *pRenderer;
   GtkTreeViewColumn *pColumn;
@@ -970,23 +987,25 @@ void dasher_preferences_dialogue_populate_actions(DasherPreferencesDialogue *pSe
   pColumnIndex[2] = ACTIONS_AUTO_COLUMN;
 
   pRenderer = gtk_cell_renderer_text_new();
-  pColumn = gtk_tree_view_column_new_with_attributes("Action", pRenderer, "text", ACTIONS_NAME_COLUMN, NULL);
+  pColumn = gtk_tree_view_column_new_with_attributes(_("Action"), pRenderer, "text", ACTIONS_NAME_COLUMN, NULL);
   g_object_set(G_OBJECT(pColumn), "expand", true, NULL);
   gtk_tree_view_append_column(GTK_TREE_VIEW(pPrivate->pActionTreeView), pColumn);
 
   pRenderer = gtk_cell_renderer_toggle_new();
   g_signal_connect(pRenderer, "toggled", (GCallback)on_action_toggle, pColumnIndex);
-  pColumn = gtk_tree_view_column_new_with_attributes("Show Button", pRenderer, "active", ACTIONS_SHOW_COLUMN, NULL);
+  /* TRANSLATORS: Show a button for the selected action in the Dasher window. */
+  pColumn = gtk_tree_view_column_new_with_attributes(_("Show Button"), pRenderer, "active", ACTIONS_SHOW_COLUMN, NULL);
   gtk_tree_view_append_column(GTK_TREE_VIEW(pPrivate->pActionTreeView), pColumn);
 
   pRenderer = gtk_cell_renderer_toggle_new();
   g_signal_connect(pRenderer, "toggled", (GCallback)on_action_toggle, pColumnIndex + 1);
-  pColumn = gtk_tree_view_column_new_with_attributes("Control Mode", pRenderer, "active", ACTIONS_CONTROL_COLUMN, NULL);
+  pColumn = gtk_tree_view_column_new_with_attributes(_("Control Mode"), pRenderer, "active", ACTIONS_CONTROL_COLUMN, NULL);
   gtk_tree_view_append_column(GTK_TREE_VIEW(pPrivate->pActionTreeView), pColumn);
 
   pRenderer = gtk_cell_renderer_toggle_new();
   g_signal_connect(pRenderer, "toggled", (GCallback)on_action_toggle, pColumnIndex + 2);
-  pColumn = gtk_tree_view_column_new_with_attributes("Auto On Stop", pRenderer, "active", ACTIONS_AUTO_COLUMN, NULL);
+  /* TRANSLATORS: Automatically perform the selected action when Dasher is stopped. */
+  pColumn = gtk_tree_view_column_new_with_attributes(_("Auto On Stop"), pRenderer, "active", ACTIONS_AUTO_COLUMN, NULL);
   gtk_tree_view_append_column(GTK_TREE_VIEW(pPrivate->pActionTreeView), pColumn);
 
   gtk_tree_view_set_model(GTK_TREE_VIEW(pPrivate->pActionTreeView), GTK_TREE_MODEL(pPrivate->pListStore));
